@@ -25,7 +25,7 @@ file chooser (see also :ref:`application flow`)::
 The variable `open_button` in this example represents a button widget instance that opens the file chooser dropdown (and
 to which the file chooser gets attached to).
 
-If the file chooser has multiple usages in the app, then the :attr:`~FileChooserPopup.submit_to` string property can be
+If the file chooser has multiple usages in the app, then the :attr:`~FileChooserPopup.submit_to` property can be
 used for to distribute the selected file path to the correct usage/process::
 
     main_app.change_flow(id_of_flow('open', 'file_chooser'),
@@ -33,8 +33,8 @@ used for to distribute the selected file path to the correct usage/process::
                                              popup_kwargs=dict(submit_to=submit_to_str_or_callable))
 
 `submit_to_str_or_callable` can be either a string or a callable. If you pass a callable then :class:`FileChooserPopup`
-will call it if the user has selected a file (by double clicking on a file name) with two arguments: the file path of
-the selected file and the dropdown widget instance::
+will call it if the user has selected a file (by touching or double clicking on a file entry). This callback receives
+two arguments: the file path of just selected file and the dropdown widget instance an and can be declared like::
 
     def submit_to_callable(file_path: str, chooser_popup: Widget):
 
@@ -59,13 +59,18 @@ automatically maintain and keep the last/historical path selections of the file
 For to record and remember the last selected path add also the app state `file_chooser_initial_path` to the
 `:ref:`app state variables` of your app.
 """
+from typing import List
+
+from kivy.app import App                                    # type: ignore
 from kivy.lang import Builder                               # type: ignore
-from kivy.properties import ListProperty, StringProperty    # type: ignore # pylint: disable=no-name-in-module
+from kivy.properties import (                               # type: ignore # pylint: disable=no-name-in-module
+    ListProperty, ObjectProperty, StringProperty)
+from kivy.uix.widget import Widget                          # type: ignore
 
 from ae.kivy_app import FlowDropDown                        # type: ignore
 
 
-__version__ = '0.1.2'
+__version__ = '0.1.5'
 
 
 Builder.load_string('''\
@@ -102,11 +107,14 @@ Builder.load_string('''\
         path: root.initial_path
         size_hint_y: None
         height: (root.attach_to.top if root.attach_to else Window.height) * 0.96 - app.main_app.font_size * 3.0
-        #dirselect: True
         on_submit:
             (root.submit_to if callable(root.submit_to) else app.main_app.on_file_chooser_submit)(args[1][0], root)
-        on_entry_added: app.on_file_chooser_entry_added(args[1])
-        on_subentry_to_entry: app.on_file_chooser_entry_added(args[1])
+        multiselect: True
+        on_selection:
+            if args[1]: \
+            (root.submit_to if callable(root.submit_to) else app.main_app.on_file_chooser_submit)(args[1][0], root)
+        on_entry_added: root.on_file_chooser_entry_added(args[1])
+        on_subentry_to_entry: root.on_file_chooser_entry_added(args[1])
         FileChooserListLayout
         FileChooserIconLayout
 
@@ -127,8 +135,47 @@ Builder.load_string('''\
 
 class FileChooserPopup(FlowDropDown):
     """ file chooser drop down container. """
-    initial_path = StringProperty()             #: initial file path displayed on opening
-    submit_to = StringProperty()                #: string for to identify which action/part requested the selected file
+    initial_path = StringProperty()     #: initial file path displayed on opening
+    submit_to = ObjectProperty("")      #: callable or string to identify which action/part requested the selected file
+
+    @staticmethod
+    def on_file_chooser_entry_added(view_entries: List[Widget]):                                # pragma: no cover
+        """ on_entry_added/on_subentry_to_entry event handler for to patch theme-related properties of Kivy FileChooser.
+
+        :param view_entries:    list of view entries for a node (icon or label) of the file chooser.
+
+        .. note::
+            This method get called for each node in the moment when a file entry widget (FileListEntry or FileIconEntry)
+            gets added to an instance of Kivy's :class:`~kivy.uix.filechooser.FileChooser` widget class.
+
+            Therefore the patches done here are not affected if the user preferences (e.g. the font size or light/dark
+            theme) get changed while a file chooser instance is displayed. In this case the user has to simply close
+            and reopen/re-instantiate the file chooser for to display the nodes with the just changed user preferences.
+
+            Theme adaption is still missing for the file chooser progress: all font sizes and colors of the currently
+            used :class:`~kivy.uix.filechooser.FileChooserProgressBase` are hard-coded, so a theme-aware progress class
+            has to be implemented (and assigned to the :attr:`~kivy.uix.filechooser.FileChooserController.progress_cls`
+            property).
+
+        """
+        app = App.get_running_app()
+        font_color = app.font_color
+        font_size = app.app_states['font_size']
+        light_theme = app.app_states['light_theme']
+        for entry in view_entries:
+            if 'FileListEntry' in str(entry):               # isinstance(entry, Factory.FileListEntry) -> TypeError
+                box, entry = entry, entry.children[0]       # children[0] is BoxLayout of FileListEntry
+                # box.children[0].children[1] is box.ids.filename
+                box.color_selected = [0.69, 0.69, 0.69, 1.0] if light_theme else [0.3, 0.3, 0.3, 1.0]
+                entry.children[1].color = font_color   # children[1] is file name label
+                entry.children[1].font_size = min(box.height * 0.90, font_size)
+                entry.children[0].color = font_color   # children[0] is file size label
+                entry.children[0].font_size = min(box.height * 0.69, font_size)
+            elif 'FileIconEntry' in str(entry):             # TypeError if using isinstance()
+                entry.children[1].color = font_color
+                entry.children[1].font_size = min(entry.children[1].height * 0.99, font_size)
+                entry.children[0].color = font_color if light_theme else [0.81, 0.81, 0.81, 1.0]
+                entry.children[0].font_size = min(entry.children[0].height * 0.90, font_size)
 
 
 class FileChooserPathSelectPopup(FlowDropDown):
